/*************************************************
* Tracker.hpp
* Copyright (c) Rennie deGraaf, 2005.  All rights reserved.
* $Id: Tracker.hpp 20 2005-07-27 01:03:31Z degraaf $
*
* Class encapsulating a single value, the data needed to track it, its upper 
* and lower bounds, and the events to be taken if those bounds are exceeded.
* See Tracker.cpp for further details.
*
* This file is part of Mardi.
*
* Mardi is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
*
* Mardi is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with Mardi; if not, write to the Free Software
* Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
**************************************************/

#ifndef TRACKER_HPP
#define TRACKER_HPP

#include <string>
using namespace std;
#include <sys/types.h>

#include <libxml++/libxml++.h>
#include <errno.h>
#include "drop_priv.h"
#include "priv_popen.h"

class Tracker 
{
  public:
    Tracker(const xmlpp::Element*, const char* file);
    ~Tracker();
    unsigned long check();
    void init();
  private:
    string callProgram(string cmd, unsigned long val=0);
    bool diff;          // true to track differences from previous value, falue otherwise
    string name;        // the name of the Tracker
    string getCmd;      // the command to get the current value
    string overCmd;     // the command to execute of the upper bound is exceeded
    string underCmd;    // the command to execute if the lower bound is exceeded
    string user;        // the user to run commands as
    uid_t uid;          // the UID of user
    string group;       // the group to run commands as
    gid_t gid;          // the GID of group
    unsigned long min;  // the lower bound
    unsigned long max;  // the upper bound
    unsigned long last; // the previous value
};

#endif // TRACKER_HPP
